@@ -7,6 +7,7 @@ import dateutil
 import time
 import wsgiref
 
+
 class CustomCSSView(BrowserView):
     """
     Renders custom CSS stored in registry
@@ -16,8 +17,8 @@ class CustomCSSView(BrowserView):
         registry = getUtility(IRegistry)
         theme_settings = registry.forInterface(IThemeSettings, False)
         self.request.response.setHeader(
-            'Content-Type',
-            'text/css; charset=utf-8',
+            "Content-Type",
+            "text/css; charset=utf-8",
         )
         dt = theme_settings.custom_css_timestamp
         # If the datetime object is timezone-naive, it is assumed to be local time.
@@ -25,7 +26,7 @@ class CustomCSSView(BrowserView):
             dt = dt.astimezone(dateutil.tz.tzlocal())
         # Format a Python datetime object as an RFC1123 date.
         self.request.response.setHeader(
-            'Last-Modified',
+            "Last-Modified",
             wsgiref.handlers.format_date_time(time.mktime(dt.timetuple())),
         )
         return theme_settings.custom_css
